==> jarvis-ironman-5.0.8.tar.gz: jarvis-ironman-5.0.8/README.md <==
[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)
[![ForTheBadge built-with-swag](http://ForTheBadge.com/images/badges/built-with-swag.svg)](https://github.com/thevickypedia/Jarvis)

[![Python 3.8](https://img.shields.io/badge/python-3.8-orange.svg)](https://www.python.org/downloads/release/python-385/)
[![Python 3.9](https://img.shields.io/badge/python-3.9-blue.svg)](https://www.python.org/downloads/release/python-391/)

###### Platform Supported
![Generic badge](https://img.shields.io/badge/Platform-MacOS-1f425f.svg)

###### Language Stats
![Language count](https://img.shields.io/github/languages/count/thevickypedia/Jarvis)
![Code coverage](https://img.shields.io/github/languages/top/thevickypedia/Jarvis)

###### Repo Stats
[![GitHub Repo stars](https://img.shields.io/github/stars/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub Repo forks](https://img.shields.io/github/forks/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub Repo watchers](https://img.shields.io/github/watchers/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)

[![GitHub](https://img.shields.io/github/license/thevickypedia/Jarvis)](LICENSE)
[![GitHub repo size](https://img.shields.io/github/repo-size/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub code size](https://img.shields.io/github/languages/code-size/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![LOC](https://img.shields.io/tokei/lines/github/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)

[![GitHub Repo issues](https://img.shields.io/github/issues-closed-raw/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub Repo issues](https://img.shields.io/github/issues-raw/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub Repo pr](https://img.shields.io/github/issues-pr-closed-raw/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub Repo pr](https://img.shields.io/github/issues-pr-raw/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)

###### Code Stats
![Modules](https://img.shields.io/github/search/thevickypedia/Jarvis/module)
![Python](https://img.shields.io/github/search/thevickypedia/Jarvis/.py)
![Threads](https://img.shields.io/github/search/thevickypedia/Jarvis/thread)
![Listener](https://img.shields.io/github/search/thevickypedia/Jarvis/listener)
![Speaker](https://img.shields.io/github/search/thevickypedia/Jarvis/speaker)
![Bash](https://img.shields.io/github/search/thevickypedia/Jarvis/.sh)
![AppleScript](https://img.shields.io/github/search/thevickypedia/Jarvis/.scpt)
![Make](https://img.shields.io/github/search/thevickypedia/Jarvis/Makefile)

###### Deployments
[![docs](https://github.com/thevickypedia/Jarvis/actions/workflows/docs.yml/badge.svg)](https://github.com/thevickypedia/Jarvis/actions/workflows/docs.yml)
[![pypi](https://github.com/thevickypedia/Jarvis/actions/workflows/python-publish.yml/badge.svg)](https://github.com/thevickypedia/Jarvis/actions/workflows/python-publish.yml)

[![Pypi-format](https://img.shields.io/pypi/format/jarvis-ironman)](https://pypi.org/project/jarvis-ironman/#files)
[![Pypi-status](https://img.shields.io/pypi/status/jarvis-ironman)](https://pypi.org/project/jarvis-ironman)
[![sourcerank](https://img.shields.io/librariesio/sourcerank/pypi/jarvis-ironman)](https://libraries.io/pypi/jarvis-ironman)

###### Activity
[![GitHub Repo created](https://img.shields.io/date/1599432310)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub commit activity](https://img.shields.io/github/commit-activity/y/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub last commit](https://img.shields.io/github/last-commit/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)

###### Development and Maintenance
[![Active Development](https://img.shields.io/badge/Development%20Level-Actively%20Developed-success.svg)](https://github.com/thevickypedia/Jarvis)
[![Actively Maintained](https://img.shields.io/badge/Maintenance%20Level-Actively%20Maintained-success.svg)](https://github.com/thevickypedia/Jarvis)

[![Maintained](https://img.shields.io/maintenance/yes/2021)](https://api.github.com/repos/thevickypedia/Jarvis)
[![Maintainer](https://img.shields.io/badge/Maintained%20By-Vignesh%20Sivanandha%20Rao-blue.svg)](https://vigneshrao.com/)

###### Reach Out
[![Ask Me | Anything ](https://img.shields.io/badge/Ask%20me-Anything-1abc9c.svg)](https://vigneshrao.com/contact)

[comment]: <> ([![Stargazers over time]&#40;https://starchart.cc/thevickypedia/Jarvis.svg&#41;]&#40;https://starchart.cc/thevickypedia/Jarvis&#41;)
[comment]: <> (![Stackoverflow reputation]&#40;https://img.shields.io/stackexchange/stackoverflow/r/13691532&#41;)
[comment]: <> (![Profile views]&#40;https://gpvc.arturio.dev/thevickypedia&#41;)

# Jarvis
IronMan's Jarvis with python

### Setup
   - Clone this [repository](https://github.com/thevickypedia/Jarvis.git) or download it from [pypi](https://pypi.org/project/jarvis-ironman/)
   - Run the following commands in command line/terminal:
        - `cd lib && chmod +x installs.sh` - Makes [installation file](https://git.io/JBnPq) as executable.
        - `python3 -m venv venv` - Creates a virtual env named `venv`
        - `source venv/bin/activate` - Activates the virtual env `venv`
        - `which python` - Validate which python is being used. Should be the one within the virtual env `venv`
        - [`bash installs.sh`](https://git.io/JBnPq) - Installs the required libraries/modules.
        - [`python3 jarvis.py`](https://git.io/JBnPz) - BOOM, you're all set, go ahead and interact with Jarvis

### ENV Variables
Environment variables are loaded from a `.env` file using the `python_dotenv` module.

<details>
<summary><strong>More on <a href="https://github.com/thevickypedia/Jarvis/wiki#environment-variables">Environment variables</a></strong></summary>

###### Default args
     Used to retrieve the current location.
- **icloud_user** - iCloud account username.
- **icloud_pass** - iCloud account password.

###### Additional args
- **git_user** - GitHub Username
- **git_pass** - GitHub Token
- **weather_api** - API Key from [openweathermap](https://openweathermap.org/) 
- **news_api** - API Key from [newsapi](https://newsapi.org/docs/client-libraries/python)
- **maps_api** - API Key for maps from [google](https://developers.google.com/maps/documentation/maps-static/get-api-key)
- **gmail_user** - Gmail account username to send and read emails.
- **gmail_pass** - Gmail account password to send and read emails.
- **robinhood_user** - Robinhood account username.
- **robinhood_pass** - Robinhood account password.
- **robinhood_qr** - Robinhood login [QR code](https://robinhood.com/account/settings)
- **birthday** - Birth date in the format DD-MM - Example: `24-April`
- **icloud_recovery** - Recovery phone number to activate lost mode on a target device - Example: `+11234567890`
- **phone_number** - To send SMS from Jarvis - Example: `+11234567890`
- **think_id** - API Key from wolfram alpha.
- **root_password** - System password for your `mac` to get the system vitals.

###### Args for [PersonalCloud](https://github.com/thevickypedia/personal_cloud) integration
- **personal_cloud_host** - Directory path which has to shared through the internet.

###### Args to control TV - Applies only for [LGWebOS](https://en.wikipedia.org/wiki/WebOS)
- **tv_client_key** - Client key to [control the TV](https://github.com/thevickypedia/Jarvis/blob/master/helper_functions/tv_controls.py) using `pywebostv` module.
- **tv_mac** - Mac address of the TV which will be retrieved by the `arp` command but just in case.

###### Args for [ip_scanner](https://github.com/thevickypedia/Jarvis/blob/master/helper_functions/ip_scanner.py) - Applies only for [Netgear routers](https://github.com/MatMaul/pynetgear#supported-routers)
- **router_pass** - Router's admin password to get the available devices using `pynetgear` module.
     > Note that this may be done even without the module by simply scanning the whole network.
  > Using the module makes it easier since the devices are already connected to the router.

###### Args for [offline-communicator](https://thevickypedia.com/jarvisoffline)
> Built for a personalized usage.
- **offline_receive_user** - Alternate gmail account username to send response from Jarvis as SMS. (`gmail_user` can be re-used)
- **offline_receive_pass** - Alternate gmail account password to send response from Jarvis as SMS. (`gmail_pass` can be re-used)
- **offline_phrase** - Secure phrase to be used for authentication purpose.
- **ngrok_auth_key** - Auth token from [ngrok](https://dashboard.ngrok.com/) - Only used for `offline_communicator`
</details>

### Coding Standards
Docstring format: [`Google`](https://google.github.io/styleguide/pyguide.html#38-comments-and-docstrings) <br>
Styling conventions: [`PEP 8`](https://www.python.org/dev/peps/pep-0008/) <br>
Clean code with pre-commit hooks: [`flake8`](https://flake8.pycqa.org/en/latest/) and 
[`isort`](https://pycqa.github.io/isort/)

### Linting
`PreCommit` will ensure linting, and the doc creation are run on every commit.

**Requirement**
<br>
`pip install --no-cache --upgrade sphinx pre-commit recommonmark`

**Usage**
<br>
`pre-commit run --all-files`

### Feature(s) Implementation
Please refer [wiki](https://github.com/thevickypedia/Jarvis/wiki) for API usage, access controls, env variables, 
features' overview and demo videos.

### Runbook
[![made-with-sphinx-doc](https://img.shields.io/badge/Made%20with-Sphinx-1f425f.svg)](https://www.sphinx-doc.org/en/master/man/sphinx-autogen.html)

https://thevickypedia.github.io/Jarvis/

## License & copyright

&copy; Vignesh Sivanandha Rao

Licensed under the [MIT License](LICENSE)

==> jarvis-ironman-5.5.2.tar.gz: jarvis-ironman-5.5.2/README.md <==
[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)
[![ForTheBadge built-with-swag](http://ForTheBadge.com/images/badges/built-with-swag.svg)](https://github.com/thevickypedia/Jarvis)

[![Python 3.8](https://img.shields.io/badge/python-3.8-orange.svg)](https://www.python.org/downloads/release/python-385/)
[![Python 3.9](https://img.shields.io/badge/python-3.9-blue.svg)](https://www.python.org/downloads/release/python-391/)

**Platform Supported**

![Generic badge](https://img.shields.io/badge/Platform-MacOS-1f425f.svg)

**Language Stats**

![Language count](https://img.shields.io/github/languages/count/thevickypedia/Jarvis)
![Code coverage](https://img.shields.io/github/languages/top/thevickypedia/Jarvis)

**Repo Stats**

[![GitHub Repo stars](https://img.shields.io/github/stars/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub Repo forks](https://img.shields.io/github/forks/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub Repo watchers](https://img.shields.io/github/watchers/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)

[![GitHub](https://img.shields.io/github/license/thevickypedia/Jarvis)](LICENSE)
[![GitHub repo size](https://img.shields.io/github/repo-size/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub code size](https://img.shields.io/github/languages/code-size/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![LOC](https://img.shields.io/tokei/lines/github/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)

[![GitHub Repo issues](https://img.shields.io/github/issues-closed-raw/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub Repo issues](https://img.shields.io/github/issues-raw/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub Repo pr](https://img.shields.io/github/issues-pr-closed-raw/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub Repo pr](https://img.shields.io/github/issues-pr-raw/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)

**Code Stats**

![Modules](https://img.shields.io/github/search/thevickypedia/Jarvis/module)
![Python](https://img.shields.io/github/search/thevickypedia/Jarvis/.py)
![Threads](https://img.shields.io/github/search/thevickypedia/Jarvis/thread)
![Listener](https://img.shields.io/github/search/thevickypedia/Jarvis/listener)
![Speaker](https://img.shields.io/github/search/thevickypedia/Jarvis/speaker)
![Bash](https://img.shields.io/github/search/thevickypedia/Jarvis/.sh)
![AppleScript](https://img.shields.io/github/search/thevickypedia/Jarvis/.scpt)
![Make](https://img.shields.io/github/search/thevickypedia/Jarvis/Makefile)

**Deployments**

[![docs](https://github.com/thevickypedia/Jarvis/actions/workflows/docs.yml/badge.svg)](https://github.com/thevickypedia/Jarvis/actions/workflows/docs.yml)
[![pypi](https://github.com/thevickypedia/Jarvis/actions/workflows/python-publish.yml/badge.svg)](https://github.com/thevickypedia/Jarvis/actions/workflows/python-publish.yml)

[![Pypi-format](https://img.shields.io/pypi/format/jarvis-ironman)](https://pypi.org/project/jarvis-ironman/#files)
[![Pypi-status](https://img.shields.io/pypi/status/jarvis-ironman)](https://pypi.org/project/jarvis-ironman)
[![sourcerank](https://img.shields.io/librariesio/sourcerank/pypi/jarvis-ironman)](https://libraries.io/pypi/jarvis-ironman)

**Activity**

[![GitHub Repo created](https://img.shields.io/date/1599432310)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub commit activity](https://img.shields.io/github/commit-activity/y/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)
[![GitHub last commit](https://img.shields.io/github/last-commit/thevickypedia/Jarvis)](https://api.github.com/repos/thevickypedia/Jarvis)

**Development and Maintenance**

[![Active Development](https://img.shields.io/badge/Development%20Level-Actively%20Developed-success.svg)](https://github.com/thevickypedia/Jarvis)
[![Actively Maintained](https://img.shields.io/badge/Maintenance%20Level-Actively%20Maintained-success.svg)](https://github.com/thevickypedia/Jarvis)

[![Maintained](https://img.shields.io/maintenance/yes/2022)](https://api.github.com/repos/thevickypedia/Jarvis)
[![Maintainer](https://img.shields.io/badge/Maintained%20By-Vignesh%20Sivanandha%20Rao-blue.svg)](https://vigneshrao.com/)

**Reach Out**

[![Ask Me | Anything ](https://img.shields.io/badge/Ask%20me-Anything-1abc9c.svg)](https://vigneshrao.com/contact)

[comment]: <> ([![Stargazers over time]&#40;https://starchart.cc/thevickypedia/Jarvis.svg&#41;]&#40;https://starchart.cc/thevickypedia/Jarvis&#41;)
[comment]: <> (![Stackoverflow reputation]&#40;https://img.shields.io/stackexchange/stackoverflow/r/13691532&#41;)
[comment]: <> (![Profile views]&#40;https://gpvc.arturio.dev/thevickypedia&#41;)

# Jarvis
IronMan's Jarvis with python

### Setup
   - Clone this [repository](https://github.com/thevickypedia/Jarvis.git) or download it from [pypi](https://pypi.org/project/jarvis-ironman/)
   - Run the following commands in command line/terminal:
        - `cd lib && chmod +x installs.sh` - Makes [installation file](https://git.io/JBnPq) as executable.
        - `python3 -m venv venv` - Creates a virtual env named `venv`
        - `source venv/bin/activate` - Activates the virtual env `venv`
        - `which python` - Validate which python is being used. Should be the one within the virtual env `venv`
        - [`bash installs.sh`](https://git.io/JBnPq) - Installs the required libraries/modules.
        - [`python3 jarvis.py`](https://git.io/JBnPz) - BOOM, you're all set, go ahead and interact with Jarvis

### ENV Variables
Environment variables are loaded from a `.env` file using the `python_dotenv` module.

<details>
<summary><strong>More on <a href="https://github.com/thevickypedia/Jarvis/wiki#environment-variables">Environment variables</a></strong></summary>

**Default args**
**[Offline communicator helper](https://thevickypedia.github.io/Jarvis/#jarvis.offline_communicator):**
- **offline_port** - Port number to initiate offline communicator on. Defaults to `4483`
- **offline_phrase** - Secure phrase to be used for authentication purpose. Defaults to `jarvis`

**Accurate Location: (Defaults to the location based on `Public IP`)**
- **icloud_user** - iCloud account username.
- **icloud_pass** - iCloud account password.

**Additional args**
- **git_user** - GitHub Username
- **git_pass** - GitHub Token
- **weather_api** - API Key from [openweathermap](https://openweathermap.org/) 
- **news_api** - API Key from [newsapi](https://newsapi.org/docs/client-libraries/python)
- **maps_api** - API Key for maps from [google](https://developers.google.com/maps/documentation/maps-static/get-api-key)
- **gmail_user** - Gmail account username to send and read emails.
- **gmail_pass** - Gmail account password to send and read emails.
- **offline_user** - Alternate gmail account username to send an SMS. (`gmail_user` can be re-used)
- **offline_pass** - Alternate gmail account password to send an SMS. (`gmail_pass` can be re-used)
- **robinhood_user** - Robinhood account username.
- **robinhood_pass** - Robinhood account password.
- **robinhood_qr** - Robinhood login [QR code](https://robinhood.com/account/settings)
- **birthday** - Birth date in the format DD-MM - Example: `24-April`
- **icloud_recovery** - Recovery phone number to activate lost mode on a target device - Example: `+11234567890`
- **phone_number** - To send SMS from Jarvis - Example: `+11234567890`
- **think_id** - API Key from wolfram alpha.
- **root_password** - System password for your `mac` to get the system vitals.
- **meeting_app** - Application where the meetings are listed. Can either be `calendar` or `outlook`

**Args for [PersonalCloud](https://github.com/thevickypedia/personal_cloud) integration**
- **personal_cloud_host** - Directory path which has to shared through the internet.

**Args to control TV** - Applies only for [LGWebOS](https://en.wikipedia.org/wiki/WebOS)
- **tv_client_key** - Client key to [control the TV](https://github.com/thevickypedia/Jarvis/blob/master/modules/tv_controls.py) using `pywebostv` module.
- **tv_mac** - Mac address of the TV which will be retrieved by the `arp` command but just in case.

**Args for [ip_scanner](https://github.com/thevickypedia/Jarvis/blob/master/modules/ip_scanner.py)** - Applies only for [Netgear routers](https://github.com/MatMaul/pynetgear#supported-routers)
- **router_pass** - Router's admin password to get the available devices using `pynetgear` module.
     > Note that this may be done even without the module by simply scanning the whole network.
  > Using the module makes it easier since the devices are already connected to the router.

**Args for [offline-communicator](https://thevickypedia.com/jarvisoffline)**
> Built for a personalized usage.
- **ngrok_auth_key** - Auth token from [ngrok](https://dashboard.ngrok.com/) - Only used for `offline_communicator`

**Args for [car_connector](https://github.com/thevickypedia/Jarvis/blob/master/modules/car_connector.py)**
> The following arguments can be used only if the vehicle is a Jaguar or a LandRover using InControl API.
- **car_email** - Email address to log in to InControl API.
- **car_pass** - Password to authenticate InControl API.

**Args for [car_controller](https://github.com/thevickypedia/Jarvis/blob/master/modules/car_controller.py)**
- **car_pin** - Master PIN for the vehicle.
</details>

### Smart Devices
A source file `smart_devices.yaml` can be used as a source for smart devices' IPs. `Jarvis` supports `MagicHome` lights and `LGWebOS` TVs.

By using `smart_devices.yaml`, the `Netgear` module can be avoided at the cost of manually updating the source file in case of IP changes.

> Note: Set a `SOURCE: True` flag in `smart_devices.yaml` otherwise the file will be removed in case of quick restarts.

### Automation Setup [Optional]
Executes pre-defined tasks at pre-defined times without any user interaction. Uses an `automation.json` file as source.

<details>
<summary><strong>Setup Instructions</strong></summary>

The JSON file should be a dictionary within a dictionary that looks like the below.

**OPTIONAL:** The key, `day` can be a `list` of days, or a `str` of a specific day or simply a `str` saying `weekday` or
`weekend` when the particular automation should be executed.

> Not having the key `day` will run the automation daily.

```json
{
  "6:00 AM": {
    "day": "weekday",
    "task": "set my bedroom lights to 50%",
    "status": false
  },
  "6:30 AM": {
    "day": ["Monday", "wednesday", "FRIDAY"],
    "task": "set my bedroom lights to 100%",
    "status": false
  },
  "8:00 AM": {
    "day": "weekend",
    "task": "set my bedroom lights to 100%",
    "status": false
  },
  "9:00 PM": {
    "task": "set my bedroom lights to 5%",
    "status": false
  }
}
```
</details>

### Coding Standards
Docstring format: [`Google`](https://google.github.io/styleguide/pyguide.html#38-comments-and-docstrings) <br>
Styling conventions: [`PEP 8`](https://www.python.org/dev/peps/pep-0008/) <br>
Clean code with pre-commit hooks: [`flake8`](https://flake8.pycqa.org/en/latest/) and 
[`isort`](https://pycqa.github.io/isort/)

### Linting
`PreCommit` will ensure linting, and the doc creation are run on every commit.

**Requirement**
<br>
`pip install --no-cache --upgrade sphinx pre-commit recommonmark`

**Usage**
<br>
`pre-commit run --all-files`

### Feature(s) Implementation
Please refer [wiki](https://github.com/thevickypedia/Jarvis/wiki) for API usage, access controls, env variables, 
features' overview and demo videos.

### Pypi Package
[![pypi-module](https://img.shields.io/badge/Software%20Repository-pypi-1f425f.svg)](https://packaging.python.org/tutorials/packaging-projects/)

[https://pypi.org/project/jarvis-ironman/](https://pypi.org/project/jarvis-ironman/)

### Runbook
[![made-with-sphinx-doc](https://img.shields.io/badge/Code%20Docs-Sphinx-1f425f.svg)](https://www.sphinx-doc.org/en/master/man/sphinx-autogen.html)

[https://thevickypedia.github.io/Jarvis/](https://thevickypedia.github.io/Jarvis/)

## License & copyright

&copy; Vignesh Sivanandha Rao

Licensed under the [MIT License](https://github.com/thevickypedia/Jarvis/blob/master/LICENSE)
